==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/ThemeConfigurationSheetTileLayoutMarginArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property show This Boolean value controls whether to display sheet margins.
 */
public data class ThemeConfigurationSheetTileLayoutMarginArgs(
    public val show: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs =
        com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs.builder()
            .show(show?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ThemeConfigurationSheetTileLayoutMarginArgs].
 */
@PulumiTagMarker
public class ThemeConfigurationSheetTileLayoutMarginArgsBuilder internal constructor() {
    private var show: Output<Boolean>? = null

    /**
     * @param value This Boolean value controls whether to display sheet margins.
     */
    @JvmName("cxnxofditruldwxp")
    public suspend fun show(`value`: Output<Boolean>) {
        this.show = value
    }

    /**
     * @param value This Boolean value controls whether to display sheet margins.
     */
    @JvmName("mpjfadsitulshltt")
    public suspend fun show(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.show = mapped
    }

    internal fun build(): ThemeConfigurationSheetTileLayoutMarginArgs =
        ThemeConfigurationSheetTileLayoutMarginArgs(
            show = show,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/ThemeConfigurationSheetTileLayoutMarginArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property show This Boolean value controls whether to display sheet margins.
 */
public data class ThemeConfigurationSheetTileLayoutMarginArgs(
    public val show: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs =
        com.pulumi.aws.quicksight.inputs.ThemeConfigurationSheetTileLayoutMarginArgs.builder()
            .show(show?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ThemeConfigurationSheetTileLayoutMarginArgs].
 */
@PulumiTagMarker
public class ThemeConfigurationSheetTileLayoutMarginArgsBuilder internal constructor() {
    private var show: Output<Boolean>? = null

    /**
     * @param value This Boolean value controls whether to display sheet margins.
     */
    @JvmName("xvtcjufmjtjcomeg")
    public suspend fun show(`value`: Output<Boolean>) {
        this.show = value
    }

    /**
     * @param value This Boolean value controls whether to display sheet margins.
     */
    @JvmName("aonwmairxqhfkjgf")
    public suspend fun show(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.show = mapped
    }

    internal fun build(): ThemeConfigurationSheetTileLayoutMarginArgs =
        ThemeConfigurationSheetTileLayoutMarginArgs(
            show = show,
        )
}
